@@ -1,8 +1,5 @@
 <?php
 
-// require_once 'random_compat/random.php'; (already required by Php70)
-// require_once 'Symfony/Component/Intl/autoload.php'; (alredy required by Intl/Icu)
-
 require_once 'Symfony/Polyfill/Apcu/autoload.php';
 require_once 'Symfony/Polyfill/Ctype/autoload.php';
 require_once 'Symfony/Polyfill/Iconv/autoload.php';
@@ -11,17 +8,13 @@ require_once 'Symfony/Polyfill/Intl/Icu/autoload.php';
 require_once 'Symfony/Polyfill/Intl/Idn/autoload.php';
 require_once 'Symfony/Polyfill/Intl/MessageFormatter/autoload.php';
 require_once 'Symfony/Polyfill/Intl/Normalizer/autoload.php';
-// require_once 'Symfony/Polyfill/Mbstring/autoload.php'; (already required by Intl/Idn/autoload.php)
-require_once 'Symfony/Polyfill/Php54/autoload.php';
-require_once 'Symfony/Polyfill/Php55/autoload.php';
-require_once 'Symfony/Polyfill/Php56/autoload.php';
-require_once 'Symfony/Polyfill/Php70/autoload.php';
-require_once 'Symfony/Polyfill/Php71/autoload.php';
+require_once 'Symfony/Polyfill/Mbstring/autoload.php';
 // require_once 'Symfony/Polyfill/Php72/autoload.php'; (already required by Intl/Idn/autoload.php)
 require_once 'Symfony/Polyfill/Php73/autoload.php';
 require_once 'Symfony/Polyfill/Php74/autoload.php';
 require_once 'Symfony/Polyfill/Php80/autoload.php';
-// require_once 'Symfony/Polyfill/Util/autoload.php'; (already required by Php56)
+require_once 'Symfony/Polyfill/Php81/autoload.php';
+require_once 'Symfony/Polyfill/Util/autoload.php';
 require_once 'Symfony/Polyfill/Uuid/autoload.php';
 
 require_once __DIR__ . '/bootstrap.php';
